@@ -1,12 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 from datetime import date
 
 from ..core import WesternCalendar, ChristianMixin
 from ..core import MON, TUE, WED, FRI
-from ..registry import iso_register
+from ..registry_tools import iso_register
 
 
 @iso_register('CL')
@@ -29,7 +25,7 @@ class Chile(WesternCalendar, ChristianMixin):
     include_immaculate_conception = True
 
     def get_variable_days(self, year):
-        days = super(Chile, self).get_variable_days(year)
+        days = super().get_variable_days(year)
         september_17 = date(year, 9, 17)
         if september_17.weekday() == MON:
             days.append((september_17, '"Bridge" holiday'))
