@@ -2,13 +2,14 @@ import warnings
 from datetime import date
 from unittest import TestCase
 
-from workalendar.core import Calendar
+from ..core import Calendar
 
 
 class GenericCalendarTest(TestCase):
     cal_class = Calendar
 
     def setUp(self):
-        warnings.simplefilter("ignore")
+        super().setUp()
+        warnings.simplefilter('ignore')
         self.year = date.today().year
         self.cal = self.cal_class()
