@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
 from unittest import TestCase
 
-from workalendar.oceania import (
+from ..oceania import (
     Australia,
     MarshallIslands,
+    NewZealand,
     # Australian territories
     AustralianCapitalTerritory,
     NewSouthWales,
@@ -17,7 +17,7 @@ from workalendar.oceania import (
     WesternAustralia
 )
 
-from workalendar.registry import registry
+from ..registry import registry
 
 AUSTRALIAN_TERRITORIES = (
     AustralianCapitalTerritory,
@@ -37,6 +37,7 @@ class RegistryOceania(TestCase):
         classes = list(classes)
         self.assertIn(Australia, classes)
         self.assertIn(MarshallIslands, classes)
+        self.assertIn(NewZealand, classes)
         for klass in AUSTRALIAN_TERRITORIES:
             self.assertIn(klass, classes)
 
